@@ -11,7 +11,7 @@ SAopt <- function(OF, algo = list(), ...) {
                   x0 = NULL,       ## initial solution
                   neighbour = NULL,
                   printDetail = TRUE,
-                  printBar = TRUE,
+                  printBar = interactive(),
                   storeF = TRUE,
                   storeSolutions = FALSE,
                   classify = FALSE,
