@@ -1,19 +1,21 @@
 ## -*- truncate-lines: t; -*-
 
 Ritter <- function(dest.dir,
-                   url = "https://site.warrington.ufl.edu/ritter/files/IPO-age.xlsx") {
+                   url = "https://site.warrington.ufl.edu/ritter/files/IPO-age.xlsx",
+                   ...) {
 
     f.name <- paste0(format(Sys.Date(), "%Y%m%d_"),
                      "IPO-age.xlsx")
     f.path <- file.path(normalizePath(dest.dir), f.name)
 
     if (!file.exists(f.path))
-        dl.result <- download.file(url, destfile = f.path)
+        dl.result <- download.file(url, destfile = f.path, ...)
     else
         dl.result <- 0
 
     if (dl.result != 0L) {
-        warning("download failed with code ", dl.result, "; see ?download.file")
+        warning("download failed with code ",
+                dl.result, "; see ?download.file")
         return(invisible(NULL))
     }
 
@@ -22,14 +24,15 @@ Ritter <- function(dest.dir,
              sQuote("openxlsx"), " is not available")
 
     data <- openxlsx::read.xlsx(f.path)
-    data <- data[, 1:11]
+    data <- data[, 1:12]
     data <- data[!apply(data, 1, function(x) all(is.na(x))), ]
     colnames(data) <- gsub("[.]", " ", colnames(data))
     cn0 <- colnames(data)
     colnames(data) <- tolower(colnames(data))
 
-    data[["offer date"]] <- as.Date(as.character(data[["offer date"]]),
-                                    format = "%Y%m%d")
+    data[["offer date"]] <- as.Date(
+        as.character(data[["offer date"]]),
+        format = "%Y%m%d")
 
     data[["rollup"]][data[["rollup"]] %in% c(".")] <- NA
     data[["rollup"]] <- as.logical(as.numeric(data[["rollup"]]))
@@ -171,9 +174,16 @@ French <- function(dest.dir,
             "6_portfolios_2x3_daily_CSV.zip",
             "F-F_Momentum_Factor_CSV.zip",
             "F-F_Momentum_Factor_daily_CSV.zip",
+
             "F-F_Research_Data_Factors_daily_CSV.zip",
+            "F-F_Research_Data_Factors_CSV.zip",
+
+            "F-F_Research_Data_5_Factors_2x3_daily_CSV.zip",
+
             "ME_Breakpoints_CSV.zip",
 
+            "Europe_5_Factors_CSV.zip",
+
             ## univariate sorts
             "Portfolios_Formed_on_ME_CSV.zip",
 
@@ -492,7 +502,7 @@ French <- function(dest.dir,
     } else if (dataset == "10_portfolios_prior_12_2_csv.zip") {
 
         if (weighting == "value")
-            i <- grep("Average Value Weighted Returns -- Monthly", txt)
+            i <- grep("(Average)? *Value Weight(ed)? Returns -- Monthly", txt)
         else if (weighting == "equal")
             i <- grep("Average Equal Weighted Returns -- Monthly", txt)
 
@@ -533,6 +543,17 @@ French <- function(dest.dir,
         ans <- txt[i:j]
         cnames <- "Mom"
 
+    } else if (dataset == "europe_5_factors_csv.zip") {
+
+        i <- grep(",Mkt-RF", txt)
+        i <- i[ c("monthly" = 1, "annual" = 2)[frequency] ]
+        j <- grep("^[, ]*$", txt)
+        j <- min( j[j > i] ) - 1
+        ans <- txt[i:j]
+
+        cnames <- c("Mkt-RF", "SMB", "HML",
+                    "RMW", "CMA", "RF")
+
     } else if (tolower(dataset) == "f-f_research_data_factors_csv.zip") {
 
         i <- grep("Mkt-RF", txt)
@@ -731,7 +752,7 @@ French <- function(dest.dir,
                           check.names = FALSE,
                           colClasses = "numeric")
         for (cc in seq_len(ncol(ans)))
-            ans[[cc]][ ans[[cc]] < -99 ] <- NA
+            ans[[cc]][ ans[[cc]] <= -99 ] <- NA
 
         timestamp <- .prepare_timestamp(ans[[1L]], frequency)
 
