@@ -414,6 +414,8 @@ trackingPortfolio <- function(var, wmin = 0, wmax = 1,
                                      bvec = b,
                                      meq  = 1L)
         ans <- qp_res$solution
+        if (!missing(var))
+            names(ans) <- colnames(var)[-1]
 
     } else if (method %in% c("ls", "LSopt")) {
 
