@@ -1,8 +1,9 @@
 resampleC <- function(..., size, cormat) {
     n <- length(data <- list(...))
-    if (n == 2L && length(cormat) == 1L)
-        cormat <- array(c(1, cormat, cormat, 1),
-                        dim = c(2L, 2L))
+    if (length(cormat) == 1L) {
+        cormat <- array(c(cormat), dim = c(n, n))
+        diag(cormat) <- 1
+    }
     m <- sapply(data, NROW)
     ns <- seq_len(n)
     defnames <- paste("var", ns, sep = "")
@@ -23,6 +24,6 @@ resampleC <- function(..., size, cormat) {
     results <- array(NA, dim = c(size,n))
     colnames(results) <- defnames
     for (i in seq_len(n))
-        results[ ,i] <- data[[i]][ii[ ,i]]
+        results[, i] <- data[[i]][ii[, i]]
     results
 }
